"use strict";
exports.__esModule = true;
exports.activityPubPlugin = void 0;
var fs = require("node:fs");
var path = require("node:path");
var activityPubPlugin = function (eleventyConfig, _a) {
    var domain = _a.domain, username = _a.username, _b = _a.displayName, displayName = _b === void 0 ? username : _b, summary = _a.summary, outbox = _a.outbox, outboxCollection = _a.outboxCollection, avatar = _a.avatar;
    eleventyConfig.on('eleventy.after', function (_a) {
        var dir = _a.dir;
        var actorDef = {
            "@context": [
                "https://www.w3.org/ns/activitystreams",
                "https://w3id.org/security/v1"
            ],
            id: "https://".concat(domain, "/").concat(username),
            type: "Person",
            preferredUsername: username,
            name: displayName,
            url: domain,
            attachments: [
                {
                    "type": "PropertyValue",
                    "name": "Website",
                    "value": "https://".concat(domain)
                }
            ],
            summary: summary,
            icon: avatar && {
                type: "Image",
                mediaType: "image/jpeg",
                url: avatar
            }
        };
        fs.writeFileSync("".concat(dir.output, "/").concat(username), JSON.stringify(actorDef));
        fs.writeFileSync("".concat(dir.output, "/").concat(username, ".json"), JSON.stringify(actorDef));
    });
    eleventyConfig.on('eleventy.after', function (_a) {
        var dir = _a.dir;
        if (!fs.existsSync("".concat(dir.output, "/.well-known"))) {
            fs.mkdirSync("".concat(dir.output, "/.well-known"));
        }
        var wf = {
            subject: "acct:".concat(username, "@").concat(domain),
            links: [
                {
                    rel: "self",
                    type: "application/activity+json",
                    href: "https://".concat(domain, "/").concat(username)
                },
                {
                    rel: "http://webfinger.net/rel/profile-page",
                    type: "text/html",
                    href: "https://".concat(domain, "/blog")
                }
            ]
        };
        fs.writeFileSync("".concat(dir.output, "/.well-known/webfinger"), JSON.stringify(wf));
    });
    eleventyConfig.addFilter("activitypubjson", function (obj) { return JSON.stringify(obj, null, 2); });
    eleventyConfig.addFilter("activitypubwrapoutbox", function (obj) { return ({
        "@context": ["https://www.w3.org/ns/activitystreams"],
        type: "OrderedCollectionPage",
        id: "https://".concat(domain, "/outbox"),
        orderedItems: obj
    }); });
    eleventyConfig.addFilter('activitypuboutboxroot', function (items) { return ({
        "@context": "https://www.w3.org/ns/activitystreams",
        "id": "https://".concat(domain, "/").concat(username, "/outbox"),
        "type": "OrderedCollection",
        "totalItems": items.length,
        "first": "https://".concat(domain, "/outbox_page"),
        "last": "https://".concat(domain, "/outbox_page")
    }); });
    eleventyConfig.addFilter('activitypuboutbox', function (items) { return ({
        "@context": "https://www.w3.org/ns/activitystreams",
        type: "OrderedCollectionPage",
        id: "https://".concat(domain, "/outbox_1"),
        orderedItems: items.sort().map(function (item) { return ({
            actor: "https://".concat(domain, "/").concat(username),
            type: "Create",
            published: item.date.toISOString(),
            id: "https://".concat(domain).concat(item.url, "publish"),
            to: [
                "https://www.w3.org/ns/activitystreams#Public"
            ],
            object: {
                attributedTo: "https://".concat(domain, "/").concat(username),
                content: "<p>".concat(item.data.title, "</p><p><a href=\"https://").concat(domain).concat(item.url, "\">https://").concat(domain).concat(item.url, "</a></p>"),
                id: "https://".concat(domain, "/").concat(item.url),
                inReplyTo: null,
                published: item.date.toISOString(),
                to: [
                    "https://www.w3.org/ns/activitystreams#Public"
                ],
                type: "Note",
                url: "https://".concat(domain).concat(item.url)
            }
        }); })
    }); });
    if (outbox) {
        eleventyConfig.addGlobalData("activitypuboutboxcollection", outboxCollection);
        eleventyConfig.on('eleventy.before', function (_a) {
            var dir = _a.dir;
            fs.mkdirSync("".concat(dir.input, "/outbox"));
            fs.copyFileSync("".concat(__dirname, "/../src/templates/outbox.njk"), path.resolve("./".concat(dir.input, "/outbox/outbox.njk")));
            fs.copyFileSync("".concat(__dirname, "/../src/templates/outbox_page.njk"), "./".concat(dir.input, "/outbox/outbox_page.njk"));
        });
        eleventyConfig.on('eleventy.after', function (_a) {
            var dir = _a.dir;
            fs.rmSync("".concat(dir.input, "/outbox"), { recursive: true, force: true });
        });
    }
};
exports.activityPubPlugin = activityPubPlugin;
